import datetime
import os

def full_path(dir_):
    """Get the expanded path of directory ``dir_``
    
    The home directory of ~ is /home/rv and home directory
    of zope is /usr/local/zope ::

    >>> full_path('~')
    '/home/rv'
    >>> full_path('~zope')
    '/usr/local/zope'


    For a non existant user `~test`, the result will be 
    current_directory/~test
::

    >>> full_path('~test')
    '/home/rv/expertpy/roopeshv.utils/roopeshv/utils/~test'


    """
    if dir_[0] == '~':
        dir_ = os.path.expanduser(dir_)
    return os.path.abspath(dir_)

def join_path(*x):
    """Join the list to form a directory path
    
    This is just a convenience function.
::

    >>> join_path('~', 'test')
    '~/test'
    >>> join_path('/home/rv', 'test')
    '/home/rv/test'
    >>> join_path('test', 'README.txt')
    'test/README.txt'


    """
    return os.path.join(*x)

def is_directory(dir_):
    """determine if dir_ is a directory ``dir_``

::

    >>> is_directory('.')
    True
    >>> is_directory('~')
    True
    >>> is_directory('/')
    True
    >>> is_directory('no/such/directory')
    False


    """
    dir_ = full_path(dir_)
    return os.path.isdir(dir_)

def get_files_in(dir_):
    """get a list of files(absolute path) in directory ``dir_``

::

    the .directory happens to exist in my computer, but for now
    the function works as intended.
    
    >>> get_files_in('/home/')
    ['/home/.directory']
    >>> '/etc/passwd' in get_files_in('/etc/') 
    True

    """
    dir_ = full_path(dir_)
    return [join_path(dir_, each) for each in os.listdir(full_path(dir_)) if not is_directory(join_path(dir_, each))]
    
def get_directories_in(dir_):
    """get a list of directories(absolute path) in directory ``dir_``

::

    >>> sorted(get_directories_in('/home/'))
    ['/home/guest', '/home/rv']
    >>> '/home/rv/Desktop' in get_directories_in('~')
    True


    """
    dir_ = full_path(dir_)
    return [join_path(dir_, each) for each in os.listdir(full_path(dir_)) if is_directory(join_path(dir_, each))]

def get_latest_file_in(dir_):
    pass
